@@ -17,14 +17,19 @@ SPECIFIC_CLASSES = {
     "ITEM_OPTIC_CAMOUFLAGE": "RandomizerPhantomCloak",
     "ITEM_SPEED_BOOSTER": "RandomizerSpeedBooster",
     "ITEM_MULTILOCKON": "RandomizerStormMissile",
+    "ITEM_LIFE_SHARDS": "RandomizerEnergyPart",
 }
 
+
 class LuaEditor:
     def __init__(self):
         self._progressive_classes = {}
         self._powerup_script = _read_powerup_lua()
         self._custom_level_scripts: dict[str, dict] = self._read_levels()
-        self._corex_replacement = {}
+        self._corex_replacement = {
+            "escue": "false",
+            "golzuna": "false",
+        }
 
     def _read_levels(self) -> dict[str, dict]:
         scenarios = {
