@@ -57,3 +57,25 @@ def patch_hints(editor: PatcherEditor, hints: list[dict]):
             hint_id: [string_key]
         }
         patch_text(editor, string_key, hint["text"])
+
+def patch_credits(editor: PatcherEditor):
+    text = editor.get_file("system/localization/credits.txt", Txt)
+    ordered_credits = list(text.strings.items())
+
+    rando_credits = {
+        "CREDIT_R_001_TITLE": "Randomizer Credits",
+        "CREDIT_R_002_SUBTITLE": "Game Patching",
+        "CREDIT_R_002": "Henrique Gemignani",
+        "CREDIT_R_003": "duncathan_salt",
+        "CREDIT_R_004_SUBTITLE": "Initial Logic Database",
+        "CREDIT_R_004": "KirbymastaH",
+        "CREDIT_R_005": "Dyceron",
+        "CREDIT_R_006_SUBTITLE": "Additional Art",
+        "CREDIT_R_007": "BigSharksZ",
+        "CREDIT_R_008": "Shawn Sigma",
+        "CREDIT_R_009_SUBTITLE": "     ",
+        "CREDIT_R_010": "With contributions from many others."
+    }
+
+    ordered_credits[1:1] = list(rando_credits.items())
+    text.strings = {k: v for k,v in ordered_credits}
